@@ -2,13 +2,13 @@
 from .verify import setToken
 from .runner import Runner, Result, EMTResult, PowerFlowResult
 from .model import Model, ModelRevision, ModelTopology
-
+from .project import Project
 from .utils import MatlabDataEncoder, DateTimeEncode
 from . import function
 
 __all__ = [
     'setToken', 'Model', 'ModelRevision', 'ModelTopology', 'Runner', 'Result',
     'PowerFlowResult', 'EMTResult', 'MatlabDataEncoder', 'DateTimeEncode',
-    'function'
+    'function', 'Project'
 ]
-__version__ = '3.0.0'
+__version__ = '3.0.1'
