@@ -1,5 +1,6 @@
 import copy
 import re
+import collections
 from .storage import Storage
 
 
@@ -87,19 +88,19 @@ class Result(object):
             else:
                 dict2[key] = val
 
-    def modify(self, data, project):
+    def modify(self, data, model):
         """
             通过指定消息修改算例文件
 
             :params: data 消息字典 {}
-            :params: project  项目
+            :params: model  项目
 
-            >>> message= result.modify(data,project)
+            >>> message= result.modify(data,model)
 
         """
         modifyData = data['data']
         payload = modifyData['payload']
-        self.__deepModify(payload, project)
+        self.__deepModify(payload, model)
 
     def getMessagesByType(self, type):
         """
@@ -276,14 +277,116 @@ class PowerFlowResult(Result):
         result.append(table)
         return result
 
-    def powerFlowModify(self, project):
+    def powerFlowModify(self, model):
         """
-            潮流数据写入 project
+            潮流数据写入 model
 
-            >>> channel= result.powerFlowModify(project)
+            >>> channel= result.powerFlowModify(model)
         """
 
         data = self.db.getMessagesByKey('power-flow-modify')
         if len(data) == 0:
             raise Exception('未找到到数据')
-        self.modify(data[0], project)
+        self.modify(data[0], model)
+
+
+class IESResult(Result):
+    """
+        综合能源结果处理类，继承 Result， 
+
+        提供快捷 plot 数据的接口函数，获取到的 plot 数据为合并后的数据格式，不在是接收时分段的数据
+
+        该类只提供 IES 仿真使用
+
+    """
+    def __init__(self, *args, **kwargs):
+        """
+            初始化
+        """
+        Result.__init__(self, *args, **kwargs)
+        self.result = {'Sankey': []}
+        self.__plotIndex = 0
+
+    def __readPlotResult(self):
+        length = self.db.getMessageLength()
+        if (length > self.__plotIndex):
+            for num in range(self.__plotIndex, length):
+                val = self.db.getMessage(num)
+                if val['type'] == 'plot':
+                    key = val['key']
+                    if key == 'Sankey':
+                        self.result['Sankey'].append(copy.deepcopy(val))
+                    else:
+                        if self.result.get(key, None) is None:
+                            self.result[key] = copy.deepcopy(val)
+                        else:
+                            traces = val['data']['traces']
+                            for i in range(len(traces)):
+                                v = traces[i]
+                                self.result[key]['data']['traces'][i][
+                                    'x'].extend(v['x'])
+                                self.result[key]['data']['traces'][i][
+                                    'y'].extend(v['y'])
+            self.__plotIndex = length
+
+    def getPlotData(self, compID, labelName, traceName='all', index=-1):
+        '''
+            获取元件ID为compID的元件，对应标签为labelName、图例名称为traceName的plot 数据的第index项
+
+            >>> result.getPlots(compID, labelName, traceName, index)
+            {...}
+        '''
+        self.__readPlotResult()
+        key = compID + '_' + labelName
+        if key not in self.result.keys():
+            raise Exception('未找到元件标志为{0},对应label为{1}的plot数据'.format(
+                compID, labelName))
+
+        traceData = self.result[key]['data']['traces']
+        if traceName != 'all':
+            traceNameList = [traceName]
+        else:
+            traceNameList = [
+                traceData[i]['name'] for i in range(len(traceData))
+            ]
+
+        startIndex = 0
+        endIndex = len(traceData[0]['x'])
+        if index >= 0:
+            startIndex = index
+            endIndex = index + 1
+
+        plotData = collections.defaultdict(lambda: {})
+        for tName in traceNameList:
+            for i in range(len(traceData)):
+                dataLen = len(traceData[i]['x'])
+                if traceData[i]['name'] == tName:
+                    if endIndex > dataLen:
+                        raise Exception('请求的index超过了plot数据序列的长度')
+                    plotData[tName]['x'] = traceData[i]['x'][
+                        startIndex:endIndex]
+                    plotData[tName]['y'] = traceData[i]['y'][
+                        startIndex:endIndex]
+
+        return plotData
+
+    def getSankey(self, index):
+        '''
+            获取第index个桑基图数据
+
+            >>> result.getSankey(index)
+            {...}
+        '''
+        self.__readPlotResult()
+        if index >= len(self.result['Sankey']):
+            raise Exception('index超过了桑基图数据序列的长度')
+        return self.result['Sankey'][index]
+
+    def getSankeyNum(self):
+        '''
+            获取桑基图数据序列的长度
+
+            >>> result.getSankeyNum()
+        '''
+        self.__readPlotResult()
+        return len(self.result['Sankey'])
\ No newline at end of file
